pub struct ProtoWireError {
pub code: i32,
pub message: String,
pub error_type: Option<String>,
}Expand description
Proto representation of WireError.
Fields
code: i32Stable client-branchable code.
message: StringInformational message.
error_type: Option<String>Concrete typed error variant, when known.
Implementations
Sourceimpl ProtoWireError
impl ProtoWireError
Sourcepub fn code(&self) -> ProtoWireErrorCode
pub fn code(&self) -> ProtoWireErrorCode
Returns the enum value of code, or the default if the field is set to an invalid enum value.
Sourcepub fn set_code(&mut self, value: ProtoWireErrorCode)
pub fn set_code(&mut self, value: ProtoWireErrorCode)
Sets code to the provided enum value.
Sourcepub fn error_type(&self) -> &str
pub fn error_type(&self) -> &str
Returns the value of error_type, or the default value if error_type is unset.