WireError

Struct WireError 

pub struct WireError {
    pub code: WireErrorCode,
    pub message: String,
    pub error_type: Option<String>,
}
Wire-safe error value. code is stable; message is informational only.

Fields

code: WireErrorCode

Stable client-branchable error code.

message: String

Human-readable informational message.

error_type: Option<String>

Concrete typed error variant, when the server can expose one safely.

Implementations

Source

impl WireError

pub fn new(code: WireErrorCode, message: impl Into<String>) -> Self

Creates a wire error with the supplied stable code and informational message.

pub fn with_error_type(self, error_type: impl Into<String>) -> Self

Attach a concrete typed error variant name to this wire error.

pub fn with_optional_error_type(self, error_type: Option<String>) -> Self

Attach an optional concrete typed error variant name to this wire error.

pub fn new_with_type( code: WireErrorCode, error_type: impl Into<String>, message: impl Into<String>, ) -> Self

Creates a wire error with a concrete typed error variant name.

pub fn not_found(message: impl Into<String>) -> Self

Not-found failure.

pub fn namespace_denied(message: impl Into<String>) -> Self

Namespace authorization failure.

pub fn sequence_conflict(message: impl Into<String>) -> Self

Durable sequence conflict failure.

pub fn unknown_query(message: impl Into<String>) -> Self

Unknown workflow query failure.

pub fn query_timeout(message: impl Into<String>) -> Self

Query timeout failure.

pub fn not_running(message: impl Into<String>) -> Self

Workflow not-running failure.

pub fn lagged(message: impl Into<String>) -> Self

Lagged stream failure.

pub fn invalid_input(message: impl Into<String>) -> Self

Invalid input failure.

pub fn backend(message: impl Into<String>) -> Self

Backend/internal failure.

pub fn query_failed(message: impl Into<String>) -> Self

Query-handler application-level failure.

pub fn deploy_denied(message: impl Into<String>) -> Self

Deploy authorization failure.

pub fn version_pinned(message: impl Into<String>) -> Self

Deploy version-pinned refusal.

pub fn not_found_with_type( error_type: impl Into<String>, message: impl Into<String>, ) -> Self

Not-found failure with a concrete typed error variant name.

pub fn not_running_with_type( error_type: impl Into<String>, message: impl Into<String>, ) -> Self

Not-running failure with a concrete typed error variant name.

pub fn backend_with_type( error_type: impl Into<String>, message: impl Into<String>, ) -> Self

Backend/internal failure with a concrete typed error variant name.