#[repr(i32)]pub enum ProtoActivityErrorKind {
Unspecified = 0,
Retryable = 1,
Terminal = 2,
}Expand description
Proto representation of ActivityErrorKind. Zero is invalid on decode.
Variants
Unspecified = 0
Missing/invalid kind.
Retryable = 1
Activity failure may be retried by the engine.
Terminal = 2
Activity failure is terminal.
Implementations
Sourceimpl ProtoActivityErrorKind
impl ProtoActivityErrorKind
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ProtoActivityErrorKind.
Sourcepub fn from_i32(value: i32) -> Option<ProtoActivityErrorKind>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ProtoActivityErrorKind>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ProtoActivityErrorKind, or None if value is not a valid variant.