pub struct ProtoActivityError {
pub kind: i32,
pub message: String,
pub details: Option<ProtoPayload>,
}Expand description
Proto representation of ActivityError.
Fields
kind: i32Explicit retryability classification.
message: StringHuman-readable error message.
details: Option<ProtoPayload>Optional structured failure details.
Implementations
Sourceimpl ProtoActivityError
impl ProtoActivityError
Sourcepub fn kind(&self) -> ProtoActivityErrorKind
pub fn kind(&self) -> ProtoActivityErrorKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: ProtoActivityErrorKind)
pub fn set_kind(&mut self, value: ProtoActivityErrorKind)
Sets kind to the provided enum value.