pub struct ProtoPauseResponse {
pub run_id: Option<ProtoRunId>,
pub status: i32,
}Expand description
Proto representation of PauseResponse (#204): the paused run and its status.
Fields
run_id: Option<ProtoRunId>The paused concrete run identifier.
status: i32The projected workflow status after the pause (Paused).
Implementations
Sourceimpl ProtoPauseResponse
impl ProtoPauseResponse
Sourcepub fn status(&self) -> ProtoWorkflowStatus
pub fn status(&self) -> ProtoWorkflowStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: ProtoWorkflowStatus)
pub fn set_status(&mut self, value: ProtoWorkflowStatus)
Sets status to the provided enum value.