Function encode_core_value
Source pub fn encode_core_value<T>(
namespace: impl Into<String>,
request_id: Option<String>,
value: &T,
) -> Result<WireEnvelope, WireError>
Serializes a core serde value into a thin wire envelope.
This helper is used for core Event, WorkflowFilter, and
WorkflowSummary values without declaring wire-clone structs for them.
Errors
Returns WireError with code backend if the core value cannot be
serialized by serde JSON.